# fldpln


[![image](https://img.shields.io/pypi/v/fldpln.svg)](https://pypi.python.org/pypi/fldpln)
[![image](https://img.shields.io/conda/vn/conda-forge/fldpln.svg)](https://anaconda.org/conda-forge/fldpln)


**Flood inundation modeling and mapping using the FLDPLN model**


-   Free software: MIT License
-   Documentation: https://xingongli.github.io/fldpln
    

## Features

-   TODO
